﻿using Microsoft.Practices.Prism.StoreApps;
using Microsoft.Practices.Prism.StoreApps.Interfaces;
using SfDataGridPrismTest.Models;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace SfDataGridPrismTest.ViewModels
{
    public class MainPageViewModel : ViewModel
    {

        public ObservableCollection<DataItem> DataItems
        {
            get { return _dataItems; }
            set { SetProperty(ref _dataItems, value); }
        }

        public string SelectedItemName
        {
            get { return _selectedItemName; }
            set { SetProperty(ref _selectedItemName, value); }
        }

        public string SelectedItemType
        {
            get { return _selectedItemType; }
            set { SetProperty(ref _selectedItemType, value); }
        }

        public DelegateCommand<string> LoadDataCommand { get; private set; }
        public DelegateCommand<DataItem> SelectionChangedCommand { get; private set; }

        public MainPageViewModel(INavigationService navigationService)
        {
            LoadDataCommand = new DelegateCommand<string>(LoadData);
            SelectionChangedCommand = new DelegateCommand<DataItem>(DataGridSelectionChanged);
        }

        private void LoadData(string args)
        {
            var noOfItems = int.Parse(args);

            var list = new List<DataItem>();

            for (int i = 1; i <= noOfItems; i++)
            {
                list.Add(new DataItem { Name = "Name " + i, Type = "Type " + i });
            }

            DataItems = new ObservableCollection<DataItem>(list);
        }

        private void DataGridSelectionChanged(DataItem item)
        {
            SelectedItemName = item.Name;
            SelectedItemType = item.Type;
        }

        private ObservableCollection<DataItem> _dataItems;
        private string _selectedItemName;
        private string _selectedItemType;
    }
}
